package com.ruoyi.web.modules.architecture.mapper;

import java.util.List;
import com.ruoyi.web.modules.architecture.domain.BizFeedingStandard;

/**
 * 饲喂标准 Mapper
 */
public interface BizFeedingStandardMapper
{
    BizFeedingStandard selectBizFeedingStandardById(Long id);

    List<BizFeedingStandard> selectBizFeedingStandardList(BizFeedingStandard query);

    int insertBizFeedingStandard(BizFeedingStandard row);

    int updateBizFeedingStandard(BizFeedingStandard row);

    int deleteBizFeedingStandardById(Long id);

    int deleteBizFeedingStandardByIds(Long[] ids);
}
